/*
Copyright (C) 2011 by Tomasz Konojacki

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

#ifndef __MICROUTF8_H__
#define __MICROUTF8_H__
#include <stdint.h>

/******************************************************************************
 * NOTE !!!                                                                   *
 *                                                                            *
 * ALL FUNCTIONS EXPECT VALID UTF-8 STRING!                                   *
 ******************************************************************************/

/* Constants. */
#define UTF8_MICROUTF8_VERSION "1.0.0"
#define UTF8_INVALID_SEQUENCE -1
#define UTF8_NOT_ENOUGH_SPACE -2
#define UTF8_BOM "\xEF\xBB\xBF"

/* Functions. */

/*
utf8_strlen() takes UTF-8 string as argument and returns number of UTF-8
characters contained in string. Returns UTF8_INVALID_SEQUENCE if UTF-8
sequence is invalid.
*/
int32_t utf8_strlen(uint8_t *str);

/*
utf8_get_nth_char() gives you requested n-th UTF-8 character from UTF-8 string.

utf8_get_nth_char() takes four arguments:
  str - UTF-8 string
  target - string where requested character will be written
  n - number (from the left) of requested character
  max_length - maximal length (including trailing \0) of character in bytes

Return value:
  1 - success
  UTF8_INVALID_SEQUENCE - supplied UTF-8 sequence was invalid
  UTF8_NOT_ENOUGH_SPACE - max_lenth is too small
*/
int8_t utf8_get_nth_char(uint8_t *str, uint8_t *target, uint32_t n, uint8_t max_length);

#endif